@@ -38,7 +38,7 @@ pub(crate) fn lint(commit_message: &CommitMessage) -> Option<Problem> {
                 last_line_location,
                 commit_text.len().saturating_sub(last_line_location),
             )]),
-            None,
+            Some("https://support.atlassian.com/jira-software-cloud/docs/what-is-an-issue/#Workingwithissues-Projectkeys".to_string()),
         ))
     }
 }
@@ -113,7 +113,7 @@ This is an example commit
                 Code::JiraIssueKeyMissing,
                 &message_1.into(),
                 Some(vec![("No JIRA Issue Key".to_string(), 19_usize, 26_usize)]),
-                None,
+                Some("https://support.atlassian.com/jira-software-cloud/docs/what-is-an-issue/#Workingwithissues-Projectkeys".parse().unwrap()),
             )),
         );
         let message_2 = "An example commit
@@ -130,7 +130,7 @@ A-123
                 Code::JiraIssueKeyMissing,
                 &message_2.into(),
                 Some(vec![("No JIRA Issue Key".to_string(), 46_usize, 6_usize)]),
-                None,
+                Some("https://support.atlassian.com/jira-software-cloud/docs/what-is-an-issue/#Workingwithissues-Projectkeys".parse().unwrap()),
             )),
         );
         let message_3 = "An example commit
@@ -147,7 +147,7 @@ JRA-
                 Code::JiraIssueKeyMissing,
                 &message_3.into(),
                 Some(vec![("No JIRA Issue Key".to_string(), 46_usize, 5_usize)]),
-                None,
+                Some("https://support.atlassian.com/jira-software-cloud/docs/what-is-an-issue/#Workingwithissues-Projectkeys".parse().unwrap()),
             )),
         );
     }
@@ -160,15 +160,15 @@ This is an example commit
 ";
         let problem = lint(&CommitMessage::from(message.to_string()));
         let actual = fmt_report(&Report::new(problem.unwrap()));
-        let expected = "JiraIssueKeyMissing
+        let expected = "JiraIssueKeyMissing (https://support.atlassian.com/jira-software-cloud/docs/what-is-an-issue/#Workingwithissues-Projectkeys)
 
-  \u{d7} Your commit message is missing a JIRA Issue Key
-   \u{256d}\u{2500}[2:1]
- 2 \u{2502} 
- 3 \u{2502} This is an example commit
-   \u{b7} \u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{252c}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}\u{2500}
-   \u{b7}              \u{2570}\u{2500}\u{2500} No JIRA Issue Key
-   \u{2570}\u{2500}\u{2500}\u{2500}\u{2500}
+  x Your commit message is missing a JIRA Issue Key
+   ,-[2:1]
+ 2 | 
+ 3 | This is an example commit
+   : ^^^^^^^^^^^^^|^^^^^^^^^^^^
+   :              `-- No JIRA Issue Key
+   `----
   help: It's important to add the issue key because it allows us to link
         code back to the motivations for doing it, and in some cases provide
         an audit trail for compliance purposes.
@@ -185,8 +185,9 @@ This is an example commit
 
     fn fmt_report(diag: &Report) -> String {
         let mut out = String::new();
-        GraphicalReportHandler::new_themed(GraphicalTheme::unicode_nocolor())
+        GraphicalReportHandler::new_themed(GraphicalTheme::none())
             .with_width(80)
+            .with_links(false)
             .render_report(&mut out, diag.as_ref())
             .unwrap();
         out
